#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 colourista
version:              0.1.0.1
visibility:           public
id:                   colourista-0.1.0.1-KcXyXznqdT1GDzaOFE3qYT
key:                  colourista-0.1.0.1-KcXyXznqdT1GDzaOFE3qYT
license:              MPL-2.0
copyright:            2020-2021 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
homepage:             https://github.com/kowainik/colourista
synopsis:             Convenient interface for printing colourful messages
description:
    Convenient interface for printing colourful messages based on the @ansi-terminal@ library.

category:             Terminal, ANSI
abi:                  f38bd1106a5ed48d89db312cbe34c91f
exposed:              True
exposed-modules:
    Colourista Colourista.IO Colourista.Pure Colourista.Short

import-dirs:          /usr/lib/ghc-8.10.5/site-local/colourista-0.1.0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/colourista-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/colourista-0.1.0.1
hs-libraries:         HScolourista-0.1.0.1-KcXyXznqdT1GDzaOFE3qYT
depends:
    ansi-terminal-0.11-366lZebL4UKAFopo4Q1x1i base-4.14.2.0
    bytestring-0.10.12.0 ghc-prim-0.6.1 text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-colourista/html/colourista.haddock
haddock-html:         /usr/share/doc/haskell-colourista/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

